PyScada Serial Extension
========================

This is a extension for PyScada to support read and write to Serial devices.


What is Working
---------------

 - nothing is test


What is not Working/Missing
---------------------------

 - Test with real hardware
 - Documentation

Installation
------------

 - pip install pyscada-serial


Contribute
----------

 - Issue Tracker: https://github.com/pyscada/PyScada-Serial/issues
 - Source Code: https://github.com/pyscada/PyScada-Serial
 

License
-------

The project is licensed under the _GNU AFFERO GENERAL PUBLIC LICENSE Version 3 (AGPLv3)_.
-
